from .__init__ import *


def isprime(max_num=100, format='string'):
    a = random.randint(2, max_num)
    problem = f"Is {a} prime?"
    if a == 2:
        solution = "Yes"
        return (problem, solution)
    if a % 2 == 0:
        solution = "No"
        return (problem, solution)
    for i in range(3, a // 2 + 1, 2):
        if a % i == 0:
            solution = "No"
            return (problem, solution)
    solution = "Yes"

    if format == 'string':
        return problem, solution
    else:
        return a, solution


is_prime = Generator('isprime', 90, isprime, ["max_num=100"])
